<?PHP

  require_once("OGoXmlRpc.inc");

  class OGoBase {
    var $timeZoneAdj;
  
    function OGoBase() {
      $this->timeZoneAdj = 0;
     }

    function parseIdFromId($id) {
      // OpenGroupware returns lots of things like:
      //   skyrix://hostname/instanceid/Id
      // in the Id field of documents, but all the
      // function calls just want that last Id part
      // as their parameters,  so this utility 
      // turns that skyrix://... Id into a ### Id.
      return substr($id, (strrpos($id, "/") + 1));
     }
   }

////////////////////////////
//  CLASS: OGoServer
///////////////////////////
  class OGoServer extends OGoBase {
    var $hostname;
    var $uri;
    var $port;
    var $client;
    function OGoServer($hostname, $uri, $port) {
      $this->OGoBase();
      $this->hostname = trim($hostname);
      $this->uri      = trim($uri);
      $this->port     = $port;
      $this->client   = new xmlrpc_client($this->uri, 
                                          $this->hostname, 
                                          $this->port);
     }
    
    function login($username, $password) {
      $this->client->setCredentials(trim($username), 
                                    trim($password));
     }
     
    function getCurrentActorId() {
    }
    
    function getCurrentActor() {
    }
    
    function getCurrentActorLogin() {
    } 

    //// XML-RPC Wrappers
    function xmlrpcmsg($method, $params = null) {
      return new xmlrpcmsg($method, $params);
     }

    function xmlrpcsend($mesg) {
      return $this->client->send($mesg);
     }   

    function xmlrpcdecode($value) {
      return useful_xmlrpc_decode($value);
     }
    
    function xmlrpcunwrap($resp) {
      if ($resp == false) {
        return "Response Is Not Valid";
       } else {
           $value = $resp->value();
           return $this->xmlrpcdecode($value);
          }
     }
    //// End XML-RPC Wrappers
   }

//////////////////////////////
// CLASS: OGoManager
/////////////////////////////
  class OGoManager extends OGoBase {
  	var $server;
  	
  	function OGoManager($server) {
  		$this->OGoBase();
  		$this->server = $server;
  	}
  	
  	function xmlrpcCallMethod($method, $parameters = null) {
    	$mesg = $this->server->xmlrpcmsg($method, $parameters);
    	$resp = $this->server->xmlrpcsend($mesg);
    	if ($resp == false)
    	  //If response is false then the message was not processed
    	  return array(0, array());
    	// resp should be a valid message response
    	$values = $this->server->xmlrpcunwrap($resp);
    	if (is_array($values))
    		return array(1, $values);
    	  else
    	  	return array(0, $values);
  	}	
   
  	function constructResults($manager, $value) {
  	 // Virtual - descendent must implement
  	}
  	
  	function constructResult($manager, $value) {
  	  // Virtual - descendent must implement
  	}
  	
  	function managerError($text) {
  	}
  }



//////////////////////////////
// CLASS: OGoDocument
/////////////////////////////
  class OGoDocument extends OGoBase {
    var $values;
    var $manager;

    function OGoDocument($manager, $values) {
      $this->OGoBase();
      $this->manager = $manager;
      $this->values = $values;
     }

    function getId() {
      return $this->values["id"];
     }

    function getVersion() {
      return $this->values["objectVersion"];
     }
     
     function constructResult($values) {
     	// Virtual Function
     	// Must be filled in by the specific OGoDocument manager  type
     }
     
    function getCurrentActorId() {
      $this->server->getCurrentActorId();
    }

    function getCurrentActor() {
      $this->server->getCurrentActor();
    }

    function getCurrentActorLogin() {
      $this->server->getCurrentActorLogin();
    }
    
     
    //// EXTENDED ATTRIBUTES ////
    function hasExtendedAttributes() {
      // Descendents need to implement this to return true if they
      // support extended attributes.
      return 0;
     }
     
    function hasExtendedAttribute($attr) {
      if ($this->hasExtendedAttributes()) {
        return isset($this->values["extendedAttrs"][$attr]);
      } else return 0;
    }
      
    function getExtendedAttribute($attr) {
      if ($this->hasExtendedAttribute($attr)) {
        return $this->values["extendedAttrs"][$attr];
      } else return "";
    }
      
    function isExtendedAttribute($attr) {
      if ($this->hasExtendedAttributes()) {
        return in_array($attr, $this->values["extendedKeys"]);
      } else return 0;
    }
      
    function setExtendedAttribute($attr, $value) {
      if ($this->isExtendedAttribute($attr))
        $this->values["extendedAttrs"][$attr] = $value;
      }    
   }

?>
