<?PHP
  require_once("OGo.inc");
  require_once("OGoDocumentComponent.inc");
  
/////////////////////////////////////////
// CLASS: OGoTaskManager
////////////////////////////////////////////
class OGoTaskManager extends OGoManager{

  function OGoTaskManager($server) {
    $this->OGoManager($server);
   }
   
  function constructResults($values) {
    $result = array();
    for($i = 0; $i < count($values); $i++)
      array_push($result, new OGoTask($this, $values[$i]));
    return $result;
   }
   
  function constructResult($values) {
    return new OGoTask($this, $values[1]);
   }
   
  function constructHistoryResults($task, $values) {
    $result = array();
    for($i = 0; $i < count($values); $i++) {
      array_push($result, new OGoTaskHistory($task, $values[$i]));
     }
    return $result;
   }
      
  function getTask($id) {
    list($result, $values)  = $this->xmlrpcCallMethod("jobs.getJobs", 
      array(new xmlrpcval($id, "string")));
    if ($result) 
      return current($this->constructResults($values));
     else 
       $this->managerError($values);
   }
   
  function getHistory($task) {
    list($result, $values) = $this->xmlrpcCallMethod("jobs.getHistory",
      array(new xmlrpcval($task->getId(), "string")));
    if ($result) 
      return $this->constructHistoryResults($task, $values); 
     else 
       $this->managerError($values);
   }                                                    

  function getDelegatedTasks() {
    list($result, $values) = $this->xmlrpcCallMethod("jobs.getDelegatedJobs");
    if ($result) 
      return $this->constructResults($values); 
     else 
       $this->managerError($values);
   }
   
  function getToDoList() {
    list($result, $values) = $this->xmlrpcCallMethod("jobs.getToDoList");
    if ($result) 
      return $this->constructResults($values); 
     else 
       $this->managerError($values);
   }  
   
  function getArchivedTasks() {
    list($result, $values) = $this->xmlrpcCallMethod("jobs.getArchivedJobs");
    if ($result) 
      return $this->constructResults($values); 
     else 
       $this->managerError($values);
   }    	
 }
 
////////////////////////////
// CLASS: OGoTask
///////////////////////////
  class OGoTask extends OGoDocument {
  	var $history;
  	
    function OGoTask($manager, $values) {
      $this->OGoDocument($manager, $values);
     }

    function getIsTeamJob() {
      return $this->values["isTeamJob"];
     }
     
    function setIsTeamJob($value) {
      $this->values["isTeamJob"] = $value;
    }

    function getName() {
      return $this->values["name"];
     }
     
    function setName($value) {
      $this->values["name"] = trim($value);
    }

    function getISOStartDate() {
      return $this->values["startDate"];
    }

    function getStartDate($format =  "d F Y (D)") {
      return date($format, iso8601_decode($this->values["startDate"]) - $this->timeZoneAdj);
     }
     
    function getISOEndDate() {
      return $this->values["endDate"];
    }

    function getEndDate($format = "d F Y (D)") {
      return date($format, iso8601_decode($this->values["endDate"]) - $this->timeZoneAdj);
     }
     
    function setEndDate($year, $month, $day) {
      $this->values["endDate"] = sprintf("%s%s%sT000000", $year, $month, $day);
    }

    function getKeywords() {
      return $this->values["keywords"];
     }
     
    function setKeyworks($value) {
      $this->values["keywords"] = trim($value);
    }

    function getCategory() {
      return $this->values["category"];
     }

    function getStatus() {
      return $this->values["status"];
     }
     
    function getVanityStatus() {
      switch ($this->values["status"]) {
        case "00_created": return "Created"; break;
        case "02_rejected": return "Rejected"; break;
        case "05_accepted": return "Accepted"; break;
        case "20_processing": return "Open"; break;    		 
        case "25_done": return "Closed"; break;
       }
      return "Undefined";	 
     }

    function getPriority() {
      return $this->values["priority"];
     }
     
    function getVanityPriority() {
      switch ($this->values["priority"]) {
      	case 1: return "Very High"; break;
      	case 2: return "High"; break;
      	case 3: return "Average"; break;
      	case 4: return "Low"; break;
      	case 5: return "Very Low"; break;
       }
      return "Undefined";
     }

    function getCreatorId() {
      return $this->values["creator"]["id"];
     }

    function getCreatorLogin() {
      return $this->values["creator"]["login"];
     }

    function getExecutorId() {
      return $this->values["executor"]["id"];
     }

    function getExecutorLogin() {
      return $this->values["executor"]["login"];
     }

    function getExecutorCN() {
      return $this->values["executor"]["info"];
     }
     
    function refresh() {
      $this->values = $this->manager->getTask($this->getId());
     }
     
    function getHistory() {
      if (is_array($this->history)) return $this->history;
       else {
         $this->history = $this->manager->getHistory($this);
         return $this->history;
        }
     }
   } 
   
///////////////////////////////////////
// Class: OGoTaskHistory
///////////////////////////////////////
class OGoTaskHistory extends OGoDocument {
  function OGoTaskHistory($document, $values) {
    $this->OGoDocument($document, $values);
   }
  
  function getComment() {
    return $this->values["comment"];
   }
 
  function getJobId() {
    return $this->values["comment"];
   }
   
  function getActorId() {
    return $this->values["actorId"];
   }
  
  function getAction() {
    return $this->values["action"];
   }
  
  function getActionDate($format =  "d F Y (D)") {
    return date($format, iso8601_decode($this->values["actionDate"])  - $this->timeZoneAdj);
   }
  
  function getActionISODate() {
    return $this->values["actionDate"];
   }
  
  function getStatus() {
    return $this->values["jobStatus"];
   }
  
  function getVanityStatus() {
    switch ($this->values["jobStatus"]) {
      case "00_created": return "Created"; break;
      case "02_rejected": return "Rejected"; break;
      case "05_accepted": return "Accepted"; break;
      case "20_processing": return "Open"; break;    		 
      case "25_done": return "Closed"; break;
     }
    return "Undefined";	 
   }  
}
?>
